==> jc-1.4.0.tar.gz: polyglot/util/ConcatenatedIterator.h <==
// public final class polyglot.util.ConcatenatedIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 515164c974927045 polyglot_util_ConcatenatedIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_ConcatenatedIterator_H_
#define _JC_polyglot_util_ConcatenatedIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_polyglot_util_ConcatenatedIterator$sub_refs	_jc_polyglot_util_ConcatenatedIterator$sub_refs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$sub_nonrefs	_jc_polyglot_util_ConcatenatedIterator$sub_nonrefs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$refs	_jc_polyglot_util_ConcatenatedIterator$refs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$nonrefs	_jc_polyglot_util_ConcatenatedIterator$nonrefs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$object	_jc_polyglot_util_ConcatenatedIterator$object;

typedef const struct _jc_polyglot_util_ConcatenatedIterator$vmethods	_jc_polyglot_util_ConcatenatedIterator$vmethods;
typedef const struct _jc_polyglot_util_ConcatenatedIterator$vtable	_jc_polyglot_util_ConcatenatedIterator$vtable;
typedef const struct _jc_polyglot_util_ConcatenatedIterator$vtype	_jc_polyglot_util_ConcatenatedIterator$vtype;

// Constructors
extern void _jc_polyglot_util_ConcatenatedIterator$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *, struct _jc_object *);
extern void _jc_polyglot_util_ConcatenatedIterator$method$_init$9294531abeefb993(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_polyglot_util_ConcatenatedIterator$method$_init$2b464e4124394a77(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *, struct _jc_object_array *);

// Virtual methods
extern void _jc_polyglot_util_ConcatenatedIterator$method$findNextItem$9bafc5b15da302df(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);
extern jboolean _jc_polyglot_util_ConcatenatedIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_ConcatenatedIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);
extern void _jc_polyglot_util_ConcatenatedIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$findNextItem$9bafc5b15da302df;
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_polyglot_util_ConcatenatedIterator$vmethods {
	void	(*findNextItem$9bafc5b15da302df)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *);
};

// Vtable
struct _jc_polyglot_util_ConcatenatedIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_ConcatenatedIterator$vmethods	polyglot_util_ConcatenatedIterator;
};

// Vtype
struct _jc_polyglot_util_ConcatenatedIterator$vtype {
	_jc_type			type;
	_jc_polyglot_util_ConcatenatedIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_ConcatenatedIterator$sub_refs {
	struct _jc_java_lang_Object$object	*next__5fitem;
	_jc_object_array	*backing__5fiterators;
};

// Reference instance fields (object)
struct _jc_polyglot_util_ConcatenatedIterator$refs {
    _jc_polyglot_util_ConcatenatedIterator$sub_refs	polyglot_util_ConcatenatedIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_ConcatenatedIterator$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_ConcatenatedIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_ConcatenatedIterator$sub_nonrefs	polyglot_util_ConcatenatedIterator;
};

// Object instance structure
struct _jc_polyglot_util_ConcatenatedIterator$object {
	_jc_polyglot_util_ConcatenatedIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_ConcatenatedIterator$vtype	*vtype;
	_jc_polyglot_util_ConcatenatedIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_ConcatenatedIterator$vtype _jc_polyglot_util_ConcatenatedIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_ConcatenatedIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_ConcatenatedIterator$class_object;

#endif	/* _JC_polyglot_util_ConcatenatedIterator_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/ConcatenatedIterator.h <==
// public final class polyglot.util.ConcatenatedIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 515164c974927045 polyglot_util_ConcatenatedIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_ConcatenatedIterator_H_
#define _JC_polyglot_util_ConcatenatedIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_polyglot_util_ConcatenatedIterator$sub_refs	_jc_polyglot_util_ConcatenatedIterator$sub_refs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$sub_nonrefs	_jc_polyglot_util_ConcatenatedIterator$sub_nonrefs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$refs	_jc_polyglot_util_ConcatenatedIterator$refs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$nonrefs	_jc_polyglot_util_ConcatenatedIterator$nonrefs;
typedef struct _jc_polyglot_util_ConcatenatedIterator$object	_jc_polyglot_util_ConcatenatedIterator$object;

typedef const struct _jc_polyglot_util_ConcatenatedIterator$vmethods	_jc_polyglot_util_ConcatenatedIterator$vmethods;
typedef const struct _jc_polyglot_util_ConcatenatedIterator$vtable	_jc_polyglot_util_ConcatenatedIterator$vtable;
typedef const struct _jc_polyglot_util_ConcatenatedIterator$vtype	_jc_polyglot_util_ConcatenatedIterator$vtype;

// Constructors
extern void _jc_polyglot_util_ConcatenatedIterator$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_ConcatenatedIterator$method$_init$9294531abeefb993(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_ConcatenatedIterator$method$_init$2b464e4124394a77(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_util_ConcatenatedIterator$method$findNextItem$9bafc5b15da302df(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_ConcatenatedIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_ConcatenatedIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_ConcatenatedIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$findNextItem$9bafc5b15da302df;
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_polyglot_util_ConcatenatedIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_polyglot_util_ConcatenatedIterator$vmethods {
	void	(*findNextItem$9bafc5b15da302df)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_polyglot_util_ConcatenatedIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_ConcatenatedIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_ConcatenatedIterator$vmethods	polyglot_util_ConcatenatedIterator;
};

// Vtype
struct _jc_polyglot_util_ConcatenatedIterator$vtype {
	_jc_type			type;
	_jc_polyglot_util_ConcatenatedIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_ConcatenatedIterator$sub_refs {
	struct _jc_java_lang_Object$object	*next__5fitem;
	_jc_object_array	*backing__5fiterators;
};

// Reference instance fields (object)
struct _jc_polyglot_util_ConcatenatedIterator$refs {
    _jc_polyglot_util_ConcatenatedIterator$sub_refs	polyglot_util_ConcatenatedIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_ConcatenatedIterator$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_ConcatenatedIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_ConcatenatedIterator$sub_nonrefs	polyglot_util_ConcatenatedIterator;
};

// Object instance structure
struct _jc_polyglot_util_ConcatenatedIterator$object {
	_jc_polyglot_util_ConcatenatedIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_ConcatenatedIterator$vtype	*vtype;
	_jc_polyglot_util_ConcatenatedIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_ConcatenatedIterator$vtype _jc_polyglot_util_ConcatenatedIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_ConcatenatedIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_ConcatenatedIterator$class_object;

#endif	/* _JC_polyglot_util_ConcatenatedIterator_H_ */
